@@ -576,17 +576,17 @@ class Update(MethodsInterface):
                 makeDirectory(rpath_old)
                 for root, dirs, files in os.walk(rpath):
                     for f in files:
-                        os.replace(os.join(rpath, d), os.path.join(rpath_old, f))
+                        os.replace(os.path.join(rpath, d), os.path.join(rpath_old, f))
                     for d in dirs:
-                        shutil.move(os.join(rpath, d), os.join(rpath_old, d))
+                        shutil.move(os.path.join(rpath, d), os.path.join(rpath_old, d))
                 p = process(emerge, "--sync", repname, stderr=STDOUT)
             if p.failed():
                 clearDirectory(rpath)
                 for root, dirs, files in os.walk(rpath_old):
                     for f in files:
-                        os.replace(os.join(rpath_old, d), os.path.join(rpath, f))
+                        os.replace(os.path.join(rpath_old, d), os.path.join(rpath, f))
                     for d in dirs:
-                        shutil.move(os.join(rpath_old, d), os.join(rpath, d))
+                        shutil.move(os.path.join(rpath_old, d), os.path.join(rpath, d))
                 removeDir(rpath_old)
                 raise UpdateError(
                     _("Failed to update the {rname} repository").format(
