@@ -194,6 +194,18 @@ class VariableClUpdateRepHosting(Variable):
     value = ''
 
 
+class VariableClUpdateRepHostingChoice(Variable):
+    type = "choice"
+    value = ''
+
+    def init(self):
+        self.label = (_("Hosting name"))
+        self.help = (_("Hosting to download from"))
+
+    def choice(self):
+        return [x[1] for x in self.Get('cl_update_inner_rep_list')] or ["Calculate"]
+
+
 class VariableClUpdateLaymanStorage(Variable):
     """
     Путь к репозиториям
@@ -621,28 +633,31 @@ class VariableClUpdateOtherSet(Variable):
     Обновить остальные оверлеи
     """
     type = "bool"
-    value = "on"
-
-
-    def init(self):
-        self.help = _("update other overlays")
-        self.label = _("Update other overlays")
+    value = ""
 
     def get(self):
+
         if self.Get('cl_update_inner_other_set'):
             return self.Get('cl_update_inner_other_set')
         return self.value
 
 
 class VariableClUpdateInnerOtherSet(Variable):
-    type = "string"
-    value = ''
+    type = "bool"
+    value = 'on'
+    metavalue = 'ON/OFF'
     opt = ["-o", "--update-other"]
 
-    def get(self):
-        if self.value in ["on", "off"]:
-            return True
-        return False
+    def init(self):
+        self.help = _("update other overlays")
+        self.label = _("Update other overlays")
+
+
+    # def get(self):
+    #     if self.value in ["on", "off"]:
+    #         return True
+    #     return False
+
 
 class VariableClUpdateOtherRepData(ReadonlyTableVariable):
     """
@@ -1685,6 +1700,7 @@ class VariableClUpdateBinhostChoice(Variable):
         return self.Get("cl_update_binhost_list")
 
 
+
 class VariableClUpdateBinhost(Variable):
     """
     Хост с бинарными обновлениями
