@@ -69,14 +69,15 @@ class Wsdl(WsdlBase):
                                         'cl_update_binhost_stable_opt_set',
                                         'cl_update_binhost_recheck_set',
                                         'cl_update_with_bdeps_opt_set',
-                                        'cl_update_other_set'
+
+                                        'cl_update_inner_other_set'
 
                                     ),
                                     expert=(
-                                        'cl_update_binhost_choice',
                                         'cl_update_sync_only_set',
-
                                         'cl_update_pretend_set',
+                                        'cl_update_binhost_choice',
+                                        'cl_update_rep_hosting_choice',
                                         'cl_update_sync_rep',
                                         'cl_update_emergelist_set',
                                         'cl_update_check_rep_set',
